@@ -33,12 +33,12 @@ def code(lines, actual_line):
     return {'code': lines, 'actual_line': [x.strip() for x in actual_line]}
 
 
-register.inclusion_tag('silk/templates/silk/inclusion/request_summary.html')(request_summary)
-register.inclusion_tag('silk/templates/silk/inclusion/profile_summary.html')(profile_summary)
-register.inclusion_tag('silk/templates/silk/inclusion/code.html')(code)
-register.inclusion_tag('silk/templates/silk/inclusion/request_menu.html')(request_menu)
-register.inclusion_tag('silk/templates/silk/inclusion/profile_menu.html')(profile_menu)
-register.inclusion_tag('silk/templates/silk/inclusion/root_menu.html')(root_menu)
-register.inclusion_tag('silk/templates/silk/inclusion/heading.html')(heading)
+register.inclusion_tag('silk/inclusion/request_summary.html')(request_summary)
+register.inclusion_tag('silk/inclusion/profile_summary.html')(profile_summary)
+register.inclusion_tag('silk/inclusion/code.html')(code)
+register.inclusion_tag('silk/inclusion/request_menu.html')(request_menu)
+register.inclusion_tag('silk/inclusion/profile_menu.html')(profile_menu)
+register.inclusion_tag('silk/inclusion/root_menu.html')(root_menu)
+register.inclusion_tag('silk/inclusion/heading.html')(heading)
 
 
