@@ -1,10 +1,15 @@
 from django.shortcuts import render_to_response
+from django.utils.decorators import method_decorator
 from django.views.generic import View
+from silk.auth import login_possibly_required, permissions_possibly_required
 from silk.models import Profile, Request
 from silk.views.sql_detail import _code
 
 
 class ProfilingDetailView(View):
+
+    @method_decorator(login_possibly_required)
+    @method_decorator(permissions_possibly_required)
     def get(self, request,  *_, **kwargs):
         profile_id = kwargs['profile_id']
         silk_request_id = kwargs.get('request_id', None)
